==> librus_api-1.0.7.tar.gz: lib/librus_api_base.dart <==
import 'dart:async';
import 'package:cookie_jar/cookie_jar.dart';
import 'package:html/parser.dart' show parse;
import 'dart:convert';
import 'package:dio/dio.dart';
import 'package:http/http.dart' as http;
import 'package:librus_api/account.dart';
import 'package:librus_api/librus_api.reflectable.dart';
import 'package:librus_api/models/serializable.dart';
import 'package:reflectable/reflectable.dart';

// ignore:unused_import
import 'package:librus_api/models/category.dart';

class Reflector extends Reflectable {
  const Reflector()
      : super(invokingCapability, typingCapability, reflectedTypeCapability,
            instanceInvokeCapability);
}

const reflector = const Reflector();

main() {}

@reflector
class LibrusApi with Serializable {
  static final String baseUrl = 'https://portal.librus.pl';
  static final String clientId = 'wmSyUMo8llDAs4y9tJVYY92oyZ6h4lAt7KCuy0Gv';
  static final String apiUrl = 'https://api.librus.pl/2.0';
  String librusToken;

  Dio _client;

  LibrusApi(String tempDir) {
    initializeReflectable();
    _client = Dio(Options(headers: {'user-agent': 'LibrusMobileApp'}));
    _client.cookieJar = PersistCookieJar(tempDir);
  }

  Future<String> signIn(String email, String password) async {
    var csrfResponse = await this._client.get(
        '$baseUrl/oauth2/authorize?client_id=$clientId&redirect_uri=http://localhost/bar&response_type=code');
    var document = parse(csrfResponse.data);
    var csrfToken = document
        .querySelector('meta[name="csrf-token"][content]')
        .attributes['content'];
    await _client.post('$baseUrl/rodzina/login/action',
        data: json.encode({'email': email, 'password': password}),
        options: Options(headers: {
          'X-CSRF-TOKEN': csrfToken,
          'Content-Type': "application/json"
        }));
    var codeResponse = await _client.get(
        '$baseUrl/oauth2/authorize?client_id=$clientId&redirect_uri=http://localhost/bar&response_type=code',
        options: Options(
            followRedirects: false, validateStatus: (status) => status < 500));
    var authCode = codeResponse.headers.value('location').split('code=')[1];
    var exchangeToken = await _client.post(
      '$baseUrl/oauth2/access_token',
      data: {
        "grant_type": "authorization_code",
        "code": authCode,
        "client_id": LibrusApi.clientId,
        "redirect_uri": "http://localhost/bar"
      },
      options: Options(headers: {"Content-Type": "application/json"}),
    );
    librusToken = exchangeToken.data['access_token'];
    return librusToken;
  }

  Future<List<Account>> get accounts async {
    http.Response response =
        await http.get('$baseUrl/api/SynergiaAccounts', headers: {
      'Authorization': 'Bearer $librusToken',
    });
    List<dynamic> accountsBody = json.decode(response.body)['accounts'];
    List<Account> accounts = [];
    accountsBody.forEach((item) {
      Account account = new Account();
      account.id = item['id'];
      account.group = item['group'];
      account.accessToken = item['accessToken'];
      account.login = item['login'];
      account.studentName = item['studentName'];
      account.scopes = item['scopes'];
      account.state = item['state'];
      account.librusToken = librusToken;
      accounts.add(account);
    });
    requestedAccounts = accounts;
    return accounts;
  }

  LibrusApi.fromJson(Map<String, dynamic> data) {
    librusToken = data['librusToken'];
    requestedAccounts = data['requestedAccounts'].map(Account.fromJson);
  }

  List<Account> requestedAccounts;
}

==> librus_api-1.0.8.tar.gz: lib/librus_api_base.dart <==
import 'dart:async';
import 'package:cookie_jar/cookie_jar.dart';
import 'package:html/parser.dart' show parse;
import 'dart:convert';
import 'package:dio/dio.dart';
import 'package:http/http.dart' as http;
import 'package:librus_api/account.dart';
import 'package:librus_api/librus_api.reflectable.dart';
import 'package:librus_api/models/serializable.dart';
import 'package:reflectable/reflectable.dart';

// ignore:unused_import
import 'package:librus_api/models/category.dart';

class Reflector extends Reflectable {
  const Reflector()
      : super(invokingCapability, typingCapability, reflectedTypeCapability,
            instanceInvokeCapability);
}

const reflector = const Reflector();

main() {}

@reflector
class LibrusApi with Serializable {
  static final String baseUrl = 'https://portal.librus.pl';
  static final String clientId = 'wmSyUMo8llDAs4y9tJVYY92oyZ6h4lAt7KCuy0Gv';
  static final String apiUrl = 'https://api.librus.pl/2.0';
  String librusToken;

  Dio _client;

  LibrusApi(String tempDir) {
    initializeReflectable();
    _client = Dio(Options(headers: {'user-agent': 'LibrusMobileApp'}));
    _client.cookieJar = PersistCookieJar(tempDir);
  }

  Future<String> signIn(String email, String password) async {
    var csrfResponse = await this._client.get(
        '$baseUrl/oauth2/authorize?client_id=$clientId&redirect_uri=http://localhost/bar&response_type=code');
    var document = parse(csrfResponse.data);
    var csrfToken = document
        .querySelector('meta[name="csrf-token"][content]')
        .attributes['content'];
    await _client.post('$baseUrl/rodzina/login/action',
        data: json.encode({'email': email, 'password': password}),
        options: Options(headers: {
          'X-CSRF-TOKEN': csrfToken,
          'Content-Type': "application/json"
        }));
    var codeResponse = await _client.get(
        '$baseUrl/oauth2/authorize?client_id=$clientId&redirect_uri=http://localhost/bar&response_type=code',
        options: Options(
            followRedirects: false, validateStatus: (status) => status < 500));
    var authCode = codeResponse.headers.value('location').split('code=')[1];
    var exchangeToken = await _client.post(
      '$baseUrl/oauth2/access_token',
      data: {
        "grant_type": "authorization_code",
        "code": authCode,
        "client_id": LibrusApi.clientId,
        "redirect_uri": "http://localhost/bar"
      },
      options: Options(headers: {"Content-Type": "application/json"}),
    );
    librusToken = exchangeToken.data['access_token'];
    return librusToken;
  }

  Future<List<Account>> get accounts async {
    http.Response response =
        await http.get('$baseUrl/api/SynergiaAccounts', headers: {
      'Authorization': 'Bearer $librusToken',
    });
    List<dynamic> accountsBody = json.decode(response.body)['accounts'];
    List<Account> accounts = [];
    accountsBody.forEach((item) {
      Account account = new Account();
      account.id = item['id'];
      account.group = item['group'];
      account.accessToken = item['accessToken'];
      account.login = item['login'];
      account.studentName = item['studentName'];
      account.scopes = item['scopes'];
      account.state = item['state'];
      account.librusToken = librusToken;
      accounts.add(account);
    });
    requestedAccounts = accounts;
    return accounts;
  }

  LibrusApi.fromJson(Map<String, dynamic> data) {
    librusToken = data['librusToken'];
    requestedAccounts = data['requestedAccounts'].map(Account.fromJson).toList();
  }

  List<Account> requestedAccounts;
}
